import { App, Button, Card, Form, Input, Modal, Select } from "antd";
import React from "react";
import { LINKTYPE } from "./const";
import { PlusOutlined, MinusCircleOutlined } from "@ant-design/icons";
import RechargeActivityLinkDTO from "./rechargeActivityLinkDTO";
import BookPromoLinkCreateDTO from "./bookPromoLinkCreateDTO";
import PagePromoLinkCreateDTO from "./pagePromoLinkCreateDTO";
import ConsumeActivityLinkDTO from "./consumeActivityLinkDTO";
import GiftActivityLinkDTO from "./giftActivityLinkDTO";
import { useAjax } from "@/Hook/useAjax";
import { addCorpAutoLinkApi } from "../../API/bookLink";
import dayJs from "dayjs";

interface Props {
    mpList: { label: string, value: number }[]
    bookPlatForm: TASK_CREATE.BookPlatFormProps[]
    visible?: boolean;
    onChange?: () => void
    onClose?: () => void
}

export const DispatchBookLink = React.createContext<BOOKLINK.DispatchBookLink | null>(null);

/**
 * 书城链接生成
 * @param param0 
 * @returns 
 */
const ModalBookLink: React.FC<Props> = ({ mpList, bookPlatForm, visible, onChange, onClose }) => {

    /********************************************/
    const { message } = App.useApp()
    const [form] = Form.useForm();
    const yueWenCreateLinkDTOList = Form.useWatch('yueWenCreateLinkDTOList', form)
    const platform = Form.useWatch('platform', form)
    const mpAccountIds = Form.useWatch('mpAccountIds', form)

    const addCorpAutoLink = useAjax((params) => addCorpAutoLinkApi(params))
    /********************************************/

    const handleOk = () => {
        form.validateFields().then((values) => {
            console.log(values)
            const params = {
                mpAccountIds: values.mpAccountIds,
                platform: values.platform,
                yueWenCreateLinkDTOList: values.yueWenCreateLinkDTOList.map(item => {
                    const { linkType, pagePromoLinkCreateDTO, bookPromoLinkCreateDTO, rechargeActivityLinkDTO, consumeActivityLinkDTO, giftActivityLinkDTO, ...rest } = item
                    if (linkType === '1') {
                        return { ...rest, pagePromoLinkCreateDTO, linkType }
                    } else if (linkType === '2') {
                        return { ...rest, bookPromoLinkCreateDTO, linkType }
                    } else if (linkType === '3') {
                        const { activityTime, display, ...ralDto } = rechargeActivityLinkDTO
                        return { ...rest, rechargeActivityLinkDTO: { ...ralDto, startTime: dayJs(activityTime[0]).format('YYYY-MM-DD'), endTime: dayJs(activityTime[1]).format('YYYY-MM-DD'), display: display?.join(',') }, linkType }
                    } else if (linkType === '4') {
                        const { activityTime, display, ...calDto } = giftActivityLinkDTO
                        return { ...rest, giftActivityLinkDTO: { ...calDto, startTime: dayJs(activityTime[0]).format('YYYY-MM-DD'), endTime: dayJs(activityTime[1]).format('YYYY-MM-DD'), display: display?.join(',') }, linkType }
                    } else if (linkType === '5') {
                        const { activityTime, display, ...galDto } = consumeActivityLinkDTO
                        return { ...rest, consumeActivityLinkDTO: { ...galDto, startTime: dayJs(activityTime[0]).format('YYYY-MM-DD'), endTime: dayJs(activityTime[1]).format('YYYY-MM-DD'), display: display?.join(',') }, linkType }
                    }
                })
            }
            addCorpAutoLink.run(params).then(res => {
                if (res?.data) {
                    message.success('添加成功')
                    onChange?.()
                }
            })
        }).catch(() => {
            form.submit()
        });
    }

    return <Modal
        title={<strong>书城链接生成</strong>}
        open={visible}
        onCancel={onClose}
        onOk={handleOk}
        width={650}
        confirmLoading={addCorpAutoLink.loading}
    >
        <Form
            form={form}
            name="newBookLink"
            labelAlign='left'
            labelCol={{ span: 5 }}
            colon={false}
            scrollToFirstError={{
                behavior: 'smooth',
                block: 'center'
            }}
            onFinishFailed={({ errorFields }) => {
                message.error(errorFields?.[0]?.errors?.[0])
            }}
            onFinish={handleOk}
            initialValues={{
                yueWenCreateLinkDTOList: [{}]
            }}
        >
            <Card title={<strong>基础信息配置</strong>} style={{ background: '#fff', marginBottom: 10 }}>
                <Form.Item label={<strong>书城</strong>} name="platform" rules={[{ required: true, message: '请选择书城!' }]}>
                    <Select
                        showSearch
                        placeholder="书城"
                        filterOption={(input, option) =>
                            ((option?.label ?? '') as string).toLowerCase().includes(input.toLowerCase())
                        }
                        allowClear
                        options={bookPlatForm.map(item => ({ value: item.platformKey, label: item.platformName }))}
                    />
                </Form.Item>
                <Form.Item label={<strong>公众号</strong>} name="mpAccountIds" rules={[{ required: true, message: '请选择公众号!' }]}>
                    <Select
                        showSearch
                        mode="multiple"
                        allowClear
                        placeholder="公众号"
                        filterOption={(input, option) =>
                            ((option?.label ?? '') as string).toLowerCase().includes(input.toLowerCase())
                        }
                        options={mpList}
                    />
                </Form.Item>
            </Card>
            <DispatchBookLink.Provider value={{ form }}>
                <Form.List name="yueWenCreateLinkDTOList">
                    {(fields, { add, remove }) => (
                        <>
                            {fields.map(({ key, name, ...restField }, index) => {

                                const yueWenCreateLinkDTO = yueWenCreateLinkDTOList?.[index]

                                return <Card
                                    title={<strong>链接信息配置{index + 1}</strong>}
                                    style={{ background: '#fff', marginBottom: 10 }}
                                    key={key}
                                    extra={yueWenCreateLinkDTOList?.length > 1 ? <div style={{ color: 'red' }} onClick={() => remove(name)}>
                                        <MinusCircleOutlined />
                                    </div> : undefined}
                                >
                                    <Form.Item
                                        {...restField}
                                        name={[name, 'linkType']}
                                        label={<strong>链接类型</strong>}
                                        rules={[{ required: true, message: '请选择链接类型!' }]}
                                    >
                                        <Select
                                            showSearch
                                            placeholder="链接类型"
                                            filterOption={(input, option) =>
                                                ((option?.label ?? '') as string).toLowerCase().includes(input.toLowerCase())
                                            }
                                            allowClear
                                            options={Object.keys(LINKTYPE).map(key => ({ label: LINKTYPE[key], value: key }))}
                                            onChange={(e) => {
                                                if (e === '1') {
                                                    setTimeout(() => {
                                                        form.setFieldsValue({
                                                            yueWenCreateLinkDTOList: yueWenCreateLinkDTOList.map((item, i) => {
                                                                if (index === i) {
                                                                    const { channelName, channelType } = item
                                                                    return { channelName, channelType, linkType: '1', pagePromoLinkCreateDTO: {} }
                                                                }
                                                                return item
                                                            })
                                                        })
                                                    }, 0)
                                                } else if (e === '2') {
                                                    setTimeout(() => {
                                                        form.setFieldsValue({
                                                            yueWenCreateLinkDTOList: yueWenCreateLinkDTOList.map((item, i) => {
                                                                if (index === i) {
                                                                    const { channelName, channelType } = item
                                                                    return { channelName, channelType, linkType: '2', bookPromoLinkCreateDTO: { forceStyle: 1, isOpenBottom: false, forceChapter: 0 } }
                                                                }
                                                                return item
                                                            })
                                                        })
                                                    }, 0)
                                                } else if (e === '3') {
                                                    setTimeout(() => {
                                                        form.setFieldsValue({
                                                            yueWenCreateLinkDTOList: yueWenCreateLinkDTOList.map((item, i) => {
                                                                if (index === i) {
                                                                    const { channelName, channelType } = item
                                                                    return { channelName, channelType, linkType: '3', rechargeActivityLinkDTO: { rechargeCount: 1, timeIsShow: 1, isDayRepeat: 0 } }
                                                                }
                                                                return item
                                                            })
                                                        })
                                                    }, 0)
                                                } else if (e === '4') {
                                                    setTimeout(() => {
                                                        form.setFieldsValue({
                                                            yueWenCreateLinkDTOList: yueWenCreateLinkDTOList.map((item, i) => {
                                                                if (index === i) {
                                                                    const { channelName, channelType } = item
                                                                    return { channelName, channelType, linkType: '4', giftActivityLinkDTO: { expire: 7, resourceType: '1' } }
                                                                }
                                                                return item
                                                            })
                                                        })
                                                    }, 0)
                                                } else if (e === '5') {
                                                    setTimeout(() => {
                                                        form.setFieldsValue({
                                                            yueWenCreateLinkDTOList: yueWenCreateLinkDTOList.map((item, i) => {
                                                                if (index === i) {
                                                                    const { channelName, channelType } = item
                                                                    return { channelName, channelType, linkType: '5', consumeActivityLinkDTO: {} }
                                                                }
                                                                return item
                                                            })
                                                        })
                                                    }, 0)
                                                }
                                            }}
                                        />
                                    </Form.Item>
                                    <Form.Item
                                        {...restField}
                                        name={[name, 'channelName']}
                                        label={<strong>渠道名称</strong>}
                                        rules={[{ required: ['1', '2'].includes(yueWenCreateLinkDTO?.linkType), message: '请输入渠道名称!' }]}
                                    >
                                        <Input placeholder="请输入渠道名称" allowClear />
                                    </Form.Item>
                                    <Form.Item
                                        {...restField}
                                        name={[name, 'channelType']}
                                        label={<strong>推广类型</strong>}
                                        rules={[{ required: ['1', '2'].includes(yueWenCreateLinkDTO?.linkType), message: '请选择推广类型!' }]}
                                    >
                                        <Select
                                            showSearch
                                            placeholder="推广类型"
                                            filterOption={(input, option) =>
                                                ((option?.label ?? '') as string).toLowerCase().includes(input.toLowerCase())
                                            }
                                            allowClear
                                            options={[{ label: '外部', value: '1' }, { label: '内部', value: '2' }]}
                                        />
                                    </Form.Item>
                                    {yueWenCreateLinkDTO?.linkType === '1' ? <PagePromoLinkCreateDTO restField={restField} name={name} /> :
                                        yueWenCreateLinkDTO?.linkType === '2' ? <BookPromoLinkCreateDTO restField={restField} name={name} platform={platform} mpAccountIds={mpAccountIds} yueWenCreateLinkDTO={yueWenCreateLinkDTO} /> :
                                            yueWenCreateLinkDTO?.linkType === '3' ? <RechargeActivityLinkDTO restField={restField} name={name} /> :
                                                yueWenCreateLinkDTO?.linkType === '4' ? <GiftActivityLinkDTO restField={restField} name={name} /> :
                                                    yueWenCreateLinkDTO?.linkType === '5' ? <ConsumeActivityLinkDTO restField={restField} name={name} /> :
                                                        undefined}
                                </Card>
                            })}
                            <Form.Item>
                                <Button type="dashed" onClick={() => add({})} block icon={<PlusOutlined />}>
                                    新增链接信息配置
                                </Button>
                            </Form.Item>
                        </>
                    )}
                </Form.List>
            </DispatchBookLink.Provider>
        </Form>
    </Modal>
};

export default React.memo(ModalBookLink);