import { App, Button, DatePicker, Input, Modal, Select, Space, Table, Tag, Typography } from "antd";
import style from '../../components/selectExternalAccount/index.less'
import { useEffect, useState } from "react";
import { getCorpAutoLinkListApi, GetCorpAutoLinkListProps } from "../../API/bookLink";
import { useAjax } from "@/Hook/useAjax";
import { getBindMpListApi } from "../../API/corpUserAssign";
import { LINKTYPE } from "./const";
const { Text, Title } = Typography;
import dayJs from 'dayjs';
import { SearchOutlined, CloseOutlined, CheckOutlined } from '@ant-design/icons'
import { bookLinkTableConfig } from "./tableConfig";

interface Props {
    bookPlatForm: TASK_CREATE.BookPlatFormProps[]
    linkData: { [x: string]: any }[]
    mpAccountId: number | null
    visible?: boolean;
    onClose?: () => void;
    onChange?: (linkStr: string, miniprogramAppid?: string, miniprogramPage?: string) => void;
}

/**
 * 选择链接
 * @param param0 
 * @returns 
 */
const SelectBookLink: React.FC<Props> = ({ bookPlatForm, linkData, mpAccountId, visible, onClose, onChange }) => {

    /*******************************************/
    const { message } = App.useApp()
    const [data, setData] = useState<{ [x: string]: any }[]>(linkData)
    const [selectAdz, setSelectAdz] = useState<number>(1)   // 选择广告主
    const [mpList, setMplist] = useState<{ label: string, value: number }[]>([])
    const [queryParams, setQueryParams] = useState<GetCorpAutoLinkListProps>({ pageNum: 1, pageSize: 20, mpAccountId })
    const [queryParamsNew, setQueryParamsNew] = useState<GetCorpAutoLinkListProps>({ pageNum: 1, pageSize: 20, mpAccountId })

    const getCorpAutoLinkList = useAjax((params) => getCorpAutoLinkListApi(params))
    const getBindMpList = useAjax(() => getBindMpListApi())
    /*******************************************/

    useEffect(() => {
        getCorpAutoLinkList.run({ ...queryParamsNew, isLink: true, mpAccountId })
    }, [queryParamsNew, mpAccountId])

    useEffect(() => {
        getBindMpList.run().then(res => {
            setMplist(res?.data?.map((item: any) => ({ label: item.name, value: item.id })))
        })
    }, [])

    const handleOk = () => {
        if (data?.every(item => item?.bookLink?.length)) {
            const linkStr = data.map(item => item.bookLink?.[0].link).join(',')
            const miniprogramAppid = data?.[0]?.bookLink?.[0]?.miniappId
            const miniprogramPage = data?.[0]?.bookLink?.[0]?.miniappPagePath
            onChange?.(linkStr, miniprogramAppid, miniprogramPage)
        } else {
            message.error('请选择链接')
        }
    }

    const handleSelectAdz = (value: number) => {
        if (value === selectAdz) {
            return
        }
        setSelectAdz(value)
    }

    return <Modal
        title={<strong>选择链接</strong>}
        open={visible}
        onCancel={onClose}
        onOk={handleOk}
        width={1200}
        className={`${style.SelectPackage}`}
        styles={{
            body: {
                padding: '0 10px 0 10px'
            }
        }}
    >
        <div className={style.content}>
            <div className={style.left}>
                <h4 className={style.title}>链接</h4>
                <div className={style.accountIdList}>
                    {data?.map((item, index) => {
                        const bookLink = item?.bookLink
                        return <div key={index} onClick={() => { handleSelectAdz(index + 1) }} className={`${style.accItem} ${selectAdz === index + 1 && style.select} `}>
                            <div><Text ellipsis={{ tooltip: true }}>{item?.link?.title}{item?.link?.desc ? `（${item?.link?.desc}）` : ''}</Text></div>
                            {bookLink?.length > 0 && <CheckOutlined style={{ color: '#1890ff' }} />}
                        </div>
                    })}
                </div>
            </div>
            <div className={style.right}>
                <Space style={{ marginBottom: 10 }} align="end" size={5} wrap>
                    <Select
                        value={queryParams?.platform}
                        onChange={(e) => setQueryParams({ ...queryParams, platform: e })}
                        showSearch
                        style={{ width: 110 }}
                        placeholder="书城"
                        filterOption={(input, option) =>
                            ((option?.label ?? '') as string).toLowerCase().includes(input.toLowerCase())
                        }
                        allowClear
                        options={bookPlatForm.map(item => ({ value: item.platformKey, label: item.platformName }))}
                    />
                    <Select
                        value={queryParams?.mpAccountId}
                        onChange={(e) => setQueryParams({ ...queryParams, mpAccountId: e })}
                        showSearch
                        style={{ width: 110 }}
                        placeholder="公众号"
                        disabled={!!mpAccountId}
                        filterOption={(input, option) =>
                            ((option?.label ?? '') as string).toLowerCase().includes(input.toLowerCase())
                        }
                        allowClear
                        options={mpList}
                    />
                    <Select
                        value={queryParams?.linkType}
                        onChange={(e) => setQueryParams({ ...queryParams, linkType: e })}
                        showSearch
                        style={{ width: 110 }}
                        placeholder="链接类型"
                        filterOption={(input, option) =>
                            ((option?.label ?? '') as string).toLowerCase().includes(input.toLowerCase())
                        }
                        allowClear
                        options={Object.keys(LINKTYPE).filter(key => ['1', '2'].includes(key)).map(key => ({ label: LINKTYPE[key], value: key }))}
                    />
                    <DatePicker.RangePicker
                        placeholder={['创建时间开始', '创建时间结束']}
                        allowClear
                        value={queryParams?.createTimeStart ? [dayJs(queryParams?.createTimeStart), dayJs(queryParams?.createTimeEnd)] : undefined}
                        onChange={(_, options) => setQueryParams({ ...queryParams, createTimeStart: options?.[0], createTimeEnd: options?.[1] })}
                    />
                    <Input placeholder='请输入渠道名称' style={{ width: 150 }} allowClear value={queryParams?.channelName} onChange={(e) => setQueryParams({ ...queryParams, channelName: e.target.value })} />
                    <Select
                        style={{ width: 110 }}
                        showSearch
                        placeholder="推广类型"
                        value={queryParams?.channelType}
                        onChange={(value) => setQueryParams({ ...queryParams, channelType: value })}
                        filterOption={(input, option) =>
                            ((option?.label ?? '') as string).toLowerCase().includes(input.toLowerCase())
                        }
                        allowClear
                        options={[{ label: '外部', value: '1' }, { label: '内部', value: '2' }]}
                    />
                    <Button type="primary" onClick={() => {
                        setQueryParamsNew({ ...queryParams, pageNum: 1 })
                    }} loading={getCorpAutoLinkList.loading} icon={<SearchOutlined />}>搜索</Button>
                </Space>

                <Table
                    tableLayout='fixed'
                    dataSource={getCorpAutoLinkList?.data?.data?.records}
                    columns={bookLinkTableConfig()}
                    loading={getCorpAutoLinkList.loading}
                    scroll={{ y: 400 }}
                    rowKey={'id'}
                    size='small'
                    bordered
                    rowSelection={{
                        selectedRowKeys: data[selectAdz - 1]?.bookLink?.map((item: any) => item?.id),
                        type: 'radio',
                        getCheckboxProps: (record: any) => ({
                            name: record.name,
                        }),
                        onChange(_, selectedRows) {
                            let newData = JSON.parse(JSON.stringify(data))
                            newData[selectAdz - 1].bookLink = selectedRows
                            setData(newData)
                        },
                    }}
                    pagination={{
                        total: getCorpAutoLinkList.data?.data?.total,
                        showTotal: (total) => <Tag color="cyan">总共{total}数据</Tag>,
                        showSizeChanger: true,
                        showLessItems: true,
                        defaultCurrent: 1,
                        defaultPageSize: 20,//默认初始的每页条数
                        current: getCorpAutoLinkList?.data?.data?.current || 1,
                        pageSize: getCorpAutoLinkList?.data?.data?.size || 20,
                        onChange: (page, pageSize) => {
                            setQueryParams({ ...queryParams, pageNum: page, pageSize })
                            setQueryParamsNew({ ...queryParamsNew, pageNum: page, pageSize })
                        }
                    }}
                />
            </div>
            <div className={style.center}>
                <Title level={5}>已选：{data[selectAdz - 1]?.bookLink?.length || 0}</Title>
                <div className={style.select_content}>
                    {data[selectAdz - 1]?.bookLink?.map(item => <div key={item.id}>
                        <Text ellipsis={{ tooltip: true }} className={style.marketingAssetName}>{item.channelName}</Text>
                        <CloseOutlined className={style.close} onClick={() => {
                            let newData = JSON.parse(JSON.stringify(data))
                            newData[selectAdz - 1].bookLink = newData[selectAdz - 1]?.bookLink?.filter((i: any) => i?.id !== item.id)
                            setData(newData)
                        }} />
                    </div>)}
                </div>
            </div>
        </div>
    </Modal>
}


export default SelectBookLink;